@@ -3,6 +3,7 @@ import sys
 import logging
 import base64
 from xml.etree import ElementTree
+from pathlib import Path
 
 from qt_material.resources import ResourseGenerator, RESOURCES_PATH
 GUI = True
@@ -40,7 +41,7 @@ template = 'material.css.template'
 
 
 # ----------------------------------------------------------------------
-def export_theme(theme='', qss=None, invert_secondary=False, extra={}, output='theme', prefix='icon:/'):
+def export_theme(theme='', qss=None, rcc=None, invert_secondary=False, extra={}, output='theme', prefix='icon:/'):
     """"""
     if not os.path.isabs(output) and not output.startswith('.'):
             output = f'.{output}'
@@ -51,6 +52,32 @@ def export_theme(theme='', qss=None, invert_secondary=False, extra={}, output='t
     with open(qss, 'w') as file:
         file.writelines(stylesheet.replace('icon:/', prefix))
 
+    if rcc:
+
+        with open(rcc, 'w') as file:
+            file.write('<RCC>\n')
+            file.write(f'  <qresource prefix="{prefix[:-2]}">\n')
+
+            if output.startswith('.'):
+                output = output[1:]
+
+            for subfolder in ['disabled', 'primary']:
+                files = os.listdir(os.path.join(
+                    os.path.abspath(output), subfolder))
+                files = filter(lambda s: s.endswith('svg'), files)
+                for filename in files:
+                    file.write(
+                        f'    <file>{output}/{subfolder}/{filename}</file>\n')
+
+            file.write('  </qresource\n')
+
+            file.write(f'  <qresource prefix="file">\n')
+            if qss:
+                file.write(f'    <file>{qss}</file>\n')
+            file.write('  </qresource\n')
+
+            file.write('</RCC>\n')
+
 
 # ----------------------------------------------------------------------
 def build_stylesheet(theme='', invert_secondary=False, extra={}, parent='theme'):
@@ -351,3 +378,8 @@ class QtStyleTools:
             button = getattr(self.dock_theme, f'pushButton_{color}')
             button.clicked.connect(self.set_color(parent, color))
 
+
+# ----------------------------------------------------------------------
+def get_hook_dirs():
+    package_folder = Path(__file__).parent
+    return [str(package_folder.absolute())]
\ No newline at end of file
